Crate intertrait

Crate intertrait 

This library provides direct casting among trait objects implemented by a type.

std usage

This crate is intended for no_std usage only.

Using this crate in a std environment will break.

If you need std usage, use the original intertrait crate instead.

For full details, refer to the original README and docs.

Modules

cast
cast module contains traits to provide cast method for various references and smart pointers.

Macros

castable_to
Declares target traits for casting implemented by a type.

Traits

CastFrom
CastFrom must be extended by a trait that wants to allow for casting into another trait.
CastFromSync
CastFromSync must be extended by a trait that is Any + Sync + Send + 'static and wants to allow for casting into another trait behind references and smart pointers especially including Arc.

Attribute Macros

cast_to
Attached on an impl item or type definition, registers traits as targets for casting.