This library provides direct casting among trait objects implemented by a type.
std usage
This crate is intended for no_std usage only.
Using this crate in a std environment will break.
If you need std usage, use the original intertrait crate instead.
For full details, refer to the original README and docs.
Modules
- cast
castmodule contains traits to providecastmethod for various references and smart pointers.
Macros
- castable_
to - Declares target traits for casting implemented by a type.
Traits
- Cast
From CastFrommust be extended by a trait that wants to allow for casting into another trait.- Cast
From Sync CastFromSyncmust be extended by a trait that isAny + Sync + Send + 'staticand wants to allow for casting into another trait behind references and smart pointers especially includingArc.
Attribute Macros
- cast_to
- Attached on an
implitem or type definition, registers traits as targets for casting.